@@ -35,6 +35,7 @@ import functools
 import json
 from time import sleep
 from datetime import datetime, timedelta
+import warnings
 
 logging.basicConfig()
 logger = logging.getLogger("AWSGetLogs")
@@ -395,6 +396,8 @@ def get_logs(
 
 
 def main():
+    warnings.warn("Deprecated. Use 'pip install aws_cloudwatch_logs' instead.", DeprecationWarning)
+
     try:
         from _version import __version__
     except Exception:
@@ -503,6 +506,7 @@ def main():
         logger.setLevel(logging.INFO)
 
     region = args.region
+
     logger.info(f"Working in: {region}")
 
     session = boto3.session.Session()
